@@ -110,9 +110,9 @@ bool ZtringListListF::Load (const Ztring &NewFileName)
 
     size_t I1=Error;
 
-    if (Name.find(_T(".csv"))!=Error)
+    if (Name.find(__T(".csv"))!=Error)
         I1=CSV_Charger();
-    if (Name.find(_T(".cfg"))!=Error)
+    if (Name.find(__T(".cfg"))!=Error)
         I1=CFG_Charger();
     if (I1!=Error)
     {
@@ -158,10 +158,10 @@ bool ZtringListListF::CSV_Charger ()
         File.From_Local((char*)Buffer, 0, BytesCount);
 
     //Separators
-    if (Separator[0]==_T("(Default)"))
+    if (Separator[0]==__T("(Default)"))
             Separator[0]=EOL;
     Ztring SeparatorT=Separator[1];
-    Separator[1]=_T(";");
+    Separator[1]=__T(";");
 
     //Writing
     Write(File);
@@ -197,27 +197,27 @@ bool ZtringListListF::CFG_Charger ()
     List.Write(Z1);
 
     Ztring SeparatorT=Separator[1];
-    Separator[1]=_T(";");
+    Separator[1]=__T(";");
 
     Ztring Propriete, Valeur, Commentaire;
 
     for (size_t Pos=0; Pos<List.size(); Pos++)
     {
         Ztring &Lu=List(Pos);
-        if (Lu.find(_T("="))>0)
+        if (Lu.find(__T("="))>0)
         {
             //Obtention du Name
-            Propriete=Lu.SubString(Ztring(), _T("="));
+            Propriete=Lu.SubString(Ztring(), __T("="));
             NettoyerEspaces(Propriete);
             //Obtention de la valeur
-            Valeur=Lu.SubString(_T("="), _T(";"), 0, Ztring_AddLastItem);
+            Valeur=Lu.SubString(__T("="), __T(";"), 0, Ztring_AddLastItem);
             NettoyerEspaces(Valeur);
         }
         //Obtention du commentaire
-        Commentaire=Lu.SubString(_T(";"), Ztring(), 0, Ztring_AddLastItem);
+        Commentaire=Lu.SubString(__T(";"), Ztring(), 0, Ztring_AddLastItem);
         NettoyerEspaces(Commentaire);
         //Ecriture
-        push_back((Propriete+_T(";")+Valeur+_T(";")+Commentaire).c_str()); //Visual C++ 6 is old...
+        push_back((Propriete+__T(";")+Valeur+__T(";")+Commentaire).c_str()); //Visual C++ 6 is old...
     }
     Separator[1]=SeparatorT;
 
@@ -245,23 +245,23 @@ bool ZtringListListF::Save (const Ztring &FileName)
         //TODO : not tested
         for (int8u I1=Backup_Nb_Max-1; I1>0; I1--)
         {
-            Ztring Z1=Name+_T(".sav"); Z1+=Ztring::ToZtring(I1);
-            Ztring Z2=Name+_T(".sav"); Z2+=Ztring::ToZtring(I1+1);
+            Ztring Z1=Name+__T(".sav"); Z1+=Ztring::ToZtring(I1);
+            Ztring Z2=Name+__T(".sav"); Z2+=Ztring::ToZtring(I1+1);
             File::Delete(Z2.c_str());
             I2=File::Move(Z1.c_str(), Z2.c_str());
             if (I2 && !Backup_Nb)
                 Backup_Nb=I2;
         }
-        Ztring Z1=Name+_T(".sav0");
+        Ztring Z1=Name+__T(".sav0");
         File::Delete(Z1.c_str());
         File::Move(Name.c_str(), Z1.c_str());
         Backup_Nb++;
     }
 
     I2=0;
-    if (Name.find(_T(".csv"))!=Error)
+    if (Name.find(__T(".csv"))!=Error)
         I2=CSV_Sauvegarder();
-    if (Name.find(_T(".cfg"))!=Error)
+    if (Name.find(__T(".cfg"))!=Error)
         I2=CFG_Sauvegarder();
 
     if (I2>0)
@@ -281,7 +281,7 @@ bool ZtringListListF::CSV_Sauvegarder ()
     if (!F.Create(Name, true))
         return Error;
 
-    if (Separator[0]==_T("(Default)"))
+    if (Separator[0]==__T("(Default)"))
         Separator[0]=EOL;
 
     F.Write(Read());
@@ -308,12 +308,12 @@ bool ZtringListListF::CFG_Sauvegarder ()
         Commentaire=Read(Pos, 2);
         if (Propriete!=Ztring())
         {
-            ToWrite+=Propriete+_T(" = ");
+            ToWrite+=Propriete+__T(" = ");
             if (Valeur!=Ztring())
-                ToWrite+=Valeur+_T(" ");
+                ToWrite+=Valeur+__T(" ");
         }
         if (Commentaire!=Ztring())
-            ToWrite+=_T("; ")+Commentaire;
+            ToWrite+=__T("; ")+Commentaire;
         ToWrite+=EOL;
     }
     F.Write(ToWrite);
@@ -325,13 +325,13 @@ bool ZtringListListF::CFG_Sauvegarder ()
 // Annulation
 bool ZtringListListF::Cancel ()
 {
-    Ztring Z1=Name+_T(".sav0"); //Visual C++ 6 patch
+    Ztring Z1=Name+__T(".sav0"); //Visual C++ 6 patch
     File::Delete(Name.c_str());
     File::Move(Z1.c_str(), Name.c_str());
     for (int8u I1=1; I1<=Backup_Nb; I1++)
     {
-        Ztring Z2=Name+_T(".sav"); Z2+=Ztring::ToZtring(I1); //Visual C++ 6 patch
-        Ztring Z3=Name+_T(".sav"); Z3+=Ztring::ToZtring(I1-1); //Visual C++ 6 patch
+        Ztring Z2=Name+__T(".sav"); Z2+=Ztring::ToZtring(I1); //Visual C++ 6 patch
+        Ztring Z3=Name+__T(".sav"); Z3+=Ztring::ToZtring(I1-1); //Visual C++ 6 patch
         File::Delete(Z3.c_str());
         File::Move(Z2.c_str(), Z3.c_str());
     }
@@ -348,10 +348,10 @@ bool ZtringListListF::Cancel ()
 bool ZtringListListF::NettoyerEspaces (Ztring &ANettoyer)
 {
     size_t Debut=0;
-    while (Debut<ANettoyer.size() && ANettoyer[Debut]==_T(' '))
+    while (Debut<ANettoyer.size() && ANettoyer[Debut]==__T(' '))
         Debut++;
     size_t Fin=ANettoyer.size()-1;
-    while (Fin!=(size_t)-2 && ANettoyer[Fin]==_T(' '))
+    while (Fin!=(size_t)-2 && ANettoyer[Fin]==__T(' '))
         Fin--;
     if (Fin>=Debut)
         ANettoyer=ANettoyer.substr(Debut, Fin-Debut+1);
